timesignaturetools.duration_and_possible_denominators_to_time_signature
=======================================================================

.. autofunction:: abjad.tools.timesignaturetools.duration_and_possible_denominators_to_time_signature.duration_and_possible_denominators_to_time_signature
